@@ -1,8 +1,7 @@
-#!/usr/bin/env python
-
 import pickle
 import sqlite3
 import re
+import os
 
 from .parser import parse_fasta
 
@@ -30,8 +29,7 @@ class Preprocessor(object):
                gene_priority_proteome='',
                versioned_ids = True):
 
-    if split < 2:
-      raise ValueError('k-sized split is invalid. Cannot be less than 2.')
+    assert split >= 2, 'k-sized split is invalid. Cannot be less than 2.'
 
     if not preprocess_format in ('sql', 'pickle'):
       raise AssertionError('Unexpected value of preprocessing format:', preprocess_format)
@@ -63,7 +61,7 @@ class Preprocessor(object):
     both k-mer and names dictionaries created. This is for compression and
     for being able to load the data in when a query is called.
     '''
-    name = self.proteome.split('/')[-1].split('.')[0]
+    name = os.path.splitext(self.proteome)[0]
     with open(name + '_' + str(self.split) + 'mers' + '.pickle', 'wb') as f:
       pickle.dump(kmer_dict, f)
     with open(name + '_names.pickle', 'wb') as f:
